import { v4 as uuid } from '@lukeed/uuid';
var MAX_EVENT_SIZE_IN_BYTES = 32 * 1024; // 32 KB
var MAX_BATCH_SIZE_IN_BYTES = 480 * 1024; // 480 KB (500 KB is the limit, leaving some padding)
var ContextBatch = /** @class */ (function () {
    function ContextBatch(maxEventCount) {
        this.id = uuid();
        this.items = [];
        this.sizeInBytes = 0;
        this.maxEventCount = Math.max(1, maxEventCount);
    }
    ContextBatch.prototype.tryAdd = function (item) {
        if (this.length === this.maxEventCount)
            return false;
        var eventSize = this.calculateSize(item.context);
        if (eventSize > MAX_EVENT_SIZE_IN_BYTES) {
            // Event exceeds Segment's limits
            return false;
        }
        if (this.sizeInBytes + eventSize <= MAX_BATCH_SIZE_IN_BYTES) {
            this.items.push(item);
            this.sizeInBytes += eventSize;
            return true;
        }
        return false;
    };
    Object.defineProperty(ContextBatch.prototype, "length", {
        get: function () {
            return this.items.length;
        },
        enumerable: false,
        configurable: true
    });
    ContextBatch.prototype.calculateSize = function (ctx) {
        return encodeURI(JSON.stringify(ctx.event)).split(/%..|i/).length;
    };
    ContextBatch.prototype.getEvents = function () {
        var events = this.items.map(function (_a) {
            var context = _a.context;
            return context.event;
        });
        return events;
    };
    ContextBatch.prototype.getContexts = function () {
        return this.items.map(function (item) { return item.context; });
    };
    ContextBatch.prototype.resolveEvents = function () {
        this.items.forEach(function (_a) {
            var resolver = _a.resolver, context = _a.context;
            return resolver(context);
        });
    };
    return ContextBatch;
}());
export { ContextBatch };
//# sourceMappingURL=context-batch.js.map